@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-my $VERSION = '0.6.0';
+my $VERSION = '0.7.0';
 
 use strict;
 # use the ToolKit
@@ -20,10 +20,11 @@ my ($begin_from_bottom, $x_scale, $y_scale, $scale_x, $scale_y, $shift_x, $shift
 my (@textfield_frame, @circle_text_frame, @textfield_entry, @entry, @text);
 my (@font, @fontsize, @begin_from_left, @eps_file_entry, @eps_filename, @eps_file_label);
 my ($tickmarks, $print_circle_boundaries, $number_of_labels, $which_field, $pidsav);
-my ($menu_help, $menu_options, $graphics_file, $radius_inner, $radius_outer, $starting_angle);
+my ($graphics_file, $radius_inner, $radius_outer, $starting_angle);
+my (@ct_clear, @tf_clear);
 my ($graphics_directory, $Bounding_X, $Bounding_Y, $x_origin, $y_origin, $debug);
 my (@shift_eps_x, @shift_eps_y, @scale_eps_x, @scale_eps_y, @fontfamily, @fontnames);
-my (@color_rgb, @rgb, @ps_color, @tk_color, @circle_radius);
+my (@color_rgb, @rgb, @ps_color, @tk_color, @circle_radius, @label_active);
 
 my @configurationfile;
 my $fontpath;
@@ -35,7 +36,7 @@ my ($label_fn, $label_id);
 # The variables we want to be saved in the configuration file
 
 my @SaveVariables = qw(delta begin_from_bottom viewer converter
-		    radius_inner tickmarks 
+		    radius_inner tickmarks
 		    print_circle_boundaries
 		    begin_from_left[0] begin_from_left[1]
 		    number_of_labels debug
@@ -77,6 +78,7 @@ my @LabelVariables = qw( text[0][0] text[0][1] text[0][2] text[0][3]
 		     color_rgb[1][7][0] color_rgb[1][7][1] color_rgb[1][7][2]
 		     color_rgb[1][9][0] color_rgb[1][9][1] color_rgb[1][9][2]
 		     shift_x shift_y scale_x scale_y starting_angle
+             label_active[0] label_active[1]
 		     eps_file_label[0] eps_file_label[1]
 		     eps_filename[0] eps_filename[1]);
 
@@ -210,72 +212,77 @@ $menu_frame -> Menubutton(-text => "File",
 					  -underline => 1]
 				       ]) -> pack(-side => 'left');
 
-my $menu_labeloptions = $menu_frame -> Menubutton(-text => "Format", -tearoff => 0,
-					       -underline => 3) -> pack(-side => 'left');
+$menu_frame -> Menubutton(-text => "Format",
+					      -underline => 3, -tearoff => 0,
+			  -menuitems => [
+                     ['command' => "Fonts and Colours",
+			          -command => \&get_fontattributes,
+			          -underline => 0],
+                     ['command' => "Angle",
+			          -command => \&get_starting_angle,
+			          -underline => 0],
+                     ['command' => "Radii",
+			          -command => \&set_circle_radius,
+			          -underline => 3],
+                     ['command' => "Page Deformation",
+			          -command => \&set_page_scaling,
+			          -underline => 0],
+                     ['command' => "Positions",
+			          -command => \&set_positions,
+			          -underline => 0],
+					 "-",
+                     ['checkbutton' => "Top label",
+				      -variable => \$label_active[1],
+			          -command => \&select_labels,
+                      -underline => 0],
+                     ['checkbutton' => "Bottom label",
+				      -variable => \$label_active[0],
+			          -command => \&select_labels,
+                      -underline => 0],
+					 "-",
+                     ['checkbutton' => "Tick Marks",
+				      -variable => \$tickmarks,
+                      -underline => 0],
+                     ['checkbutton' => "Circle Boundaries",
+				      -variable => \$print_circle_boundaries,
+                      -underline => 0],
+					 "-",
+                     ['command' => "Graphics",
+			          -command => \&get_graphics,
+			          -underline => 0]
+				       ]) -> pack(-side => 'left');
 
-$menu_labeloptions -> command(-label => "Fonts and Colours",
-			      -command => \&get_fontattributes,
-			      -underline => 0);
+$menu_frame -> Menubutton(-text => "Options",
+					      -underline => 0, -tearoff => 0,
+			  -menuitems => [
+                     ['command' => "Previewer",
+			          -command => \&get_previewer,
+			          -underline => 0],
+                     ['command' => "Graphics converter",
+			          -command => \&get_converter,
+			          -underline => 0],
+					 "-",
+                     ['command' => "Load options",
+			          -command => \&read_configuration,
+			          -underline => 0],
+                     ['command' => "Save options",
+			          -command => \&write_configuration,
+			          -underline => 0]
+				       ]) -> pack(-side => 'left');
 
-$menu_labeloptions -> command(-label => "Angle",
-			      -command => \&get_starting_angle,
-			      -underline => 0);
-
-$menu_labeloptions -> command(-label => "Radii",
-			      -command => \&set_circle_radius,
-			      -underline => 3);
-
-$menu_labeloptions -> command(-label => "Page Deformation",
-			      -command => \&set_page_scaling,
-			      -underline => 0 );
-
-$menu_labeloptions -> command(-label => "Positions",
-			      -command => \&set_positions,
-			      -underline => 0 );
-
-$menu_labeloptions -> checkbutton(-label => "Tick Marks",
-                                  -underline => 0,
-				  -variable => \$tickmarks);
-
-$menu_labeloptions -> checkbutton(-label => "Circle Boundaries",
-                                  -underline => 0,
-				  -variable => \$print_circle_boundaries);
-
-$menu_labeloptions -> command(-label => "Graphics",
-			      -command => \&get_graphics,
-			      -underline => 0 );
-
-$menu_options = $menu_frame -> Menubutton(-text => "Options", -tearoff => 0,
-					  -underline => 0) -> pack(-side => 'left');
-
-$menu_options -> command(-label => "Previewer",
-			 -command => \&get_previewer,
-			 -underline => 0);
-
-$menu_options -> command(-label => "Graphics converter",
-			 -command => \&get_converter,
-			 -underline => 0);
-
-$menu_options -> command(-label => "Load options",
-			 -command => \&read_configuration,
-			 -underline => 0);
-
-$menu_options -> command(-label => "Save options",
-			 -command => \&write_configuration,
-			 -underline => 0);
-
-## The help entry
-$menu_help = $menu_frame -> Menubutton(-text => "Help", -tearoff => 0,,
-				       -underline => 0) -> pack(-side => 'left');
-$menu_help -> command(-label => "Help",
-		      -command => \&help_window,
-		      -underline => 0);
-$menu_help -> command(-label => "About",
-		      -command => \&about_window,
-		      -underline => 0);
+$menu_frame -> Menubutton(-text => "Help",
+				          -underline => 0, -tearoff => 0,
+			  -menuitems => [
+                     ['command' => "Help",
+		              -command => \&help_window,
+		              -underline => 0],
+                     ['command' => "About",
+		              -command => \&about_window,
+		              -underline => 0]
+				       ]) -> pack(-side => 'left');
 
 #$menu_frame -> Button(-text => "label", -command => \&print_label) -> pack(-side => 'left');
-#$menu_frame -> Button(-text => "Preview", -command => \&preview) -> pack(-side => 'left');
+$menu_frame -> Button(-text => "Preview", -command => \&preview) -> pack(-side => 'left');
 
 # Test for Canvas don't use it
 #$menu_frame -> Button(-text => "CANVAS", -command => \&create_canvas) -> pack(-side => 'left');
@@ -341,14 +348,14 @@ for ( my $j=0; $j < $number_of_labels; $j++) {
   }
 }
 
-$circle_text_frame[0] -> Button(-text => "clear",
+$ct_clear[0] = $circle_text_frame[0] -> Button(-text => "clear",
 				-command => sub{clear_circle_text (0)} ) -> pack();
-$circle_text_frame[1] -> Button(-text => "clear",
+$ct_clear[1] = $circle_text_frame[1] -> Button(-text => "clear",
 				-command => sub{clear_circle_text (1)} ) -> pack();
 
-$textfield_frame[0] -> Button(-text => "clear",
+$tf_clear[0] = $textfield_frame[0] -> Button(-text => "clear",
 				-command => sub{clear_textfields (0)} ) -> pack();
-$textfield_frame[1] -> Button(-text => "clear",
+$tf_clear[1] = $textfield_frame[1] -> Button(-text => "clear",
 				-command => sub{clear_textfields (1)} ) -> pack();
 
 # Was a Label filename specified?
@@ -569,6 +576,10 @@ sub defaults {
   # Number of labels on a sheet (very incomplete use of this variable)
   $number_of_labels = 2;
 
+  # All labels active
+  $label_active[0] = 1;
+  $label_active[1] = 1;
+
   # A variable to define the backround which is treated as an additional circle or textfield
   $number_of_background = 9;
 
@@ -739,6 +750,13 @@ sub update_display {
     for ($i = 0; $i < 4; $i++) {
       $entry[$j][$i] -> configure(-foreground => $tk_color[$j][$i]);
       $textfield_entry[$j][$i] -> configure(-foreground => $tk_color[$j][$i+4]);
+      if ($label_active[$j]) {
+        $entry[$j][$i] -> configure(-state => 'normal');
+        $textfield_entry[$j][$i] -> configure(-state => 'normal');
+      } else {
+        $entry[$j][$i] -> configure(-state => 'disabled');
+        $textfield_entry[$j][$i] -> configure(-state => 'disabled');
+      }
     }
   }
 
@@ -972,7 +990,7 @@ sub print_circles {
 
   print PS_FILE "gsave\n";
 
-  for ($label_no = 0;$label_no < $number_of_labels ;$label_no++) {
+  for ($label_no = 0; $label_no < $number_of_labels; $label_no++) {
 
     print PS_FILE "$x_origin mm $y_origin mm translate \n"; # shift the origin of drawing
 
@@ -980,6 +998,8 @@ sub print_circles {
     print PS_FILE "gsave\n";
     print PS_FILE "0 0 $radius_outer mm 0 360 arc clip\n";
 
+    if ($label_active[$label_no]) {
+
     # First we need the circles in the background color
     print PS_FILE "$ps_color[$label_no][$number_of_background] setrgbcolor\n";
     print PS_FILE "0 0 $radius_outer mm 0 360 arc\n";
@@ -1014,28 +1034,32 @@ sub print_circles {
     print PS_FILE "/$fontfamily[$label_no][0] findfont\n"; # The font we want
     print PS_FILE "$fontsize[$label_no][0] scalefont setfont\n"; # scaling the font
     print PS_FILE "$ps_color[$label_no][0] setrgbcolor \n";
-    print PS_FILE "($text[$label_no][0])" ," ", $fontsize[$label_no][0] ," ",  -$starting_angle +90," ", $circle_radius[$label_no][0]," mm OutsideCircletext\n";
+    print PS_FILE "($text[$label_no][0])", " ", $fontsize[$label_no][0], " ", -$starting_angle +90, " ",
+                    $circle_radius[$label_no][0], " mm OutsideCircletext\n";
 
     # Inner upper circle or textfield
     print PS_FILE "/$fontfamily[$label_no][1] reencodeISO def\n";
     print PS_FILE "/$fontfamily[$label_no][1] findfont\n";
     print PS_FILE "$fontsize[$label_no][1] scalefont setfont\n";
     print PS_FILE "$ps_color[$label_no][1] setrgbcolor \n";
-    print PS_FILE "($text[$label_no][1])" ," ", $fontsize[$label_no][1]," ",  -$starting_angle +90 , " " , $circle_radius[$label_no][1] , " mm OutsideCircletext\n";
+    print PS_FILE "($text[$label_no][1])", " ", $fontsize[$label_no][1], " ", -$starting_angle +90, " ",
+                    $circle_radius[$label_no][1], " mm OutsideCircletext\n";
 
     # Inner lower circle or textfield
     print PS_FILE "/$fontfamily[$label_no][2] reencodeISO def\n";
     print PS_FILE "/$fontfamily[$label_no][2] findfont\n";
     print PS_FILE " $fontsize[$label_no][2] scalefont setfont\n";
     print PS_FILE "$ps_color[$label_no][2] setrgbcolor \n";
-    print PS_FILE "($text[$label_no][2])" ," ", $fontsize[$label_no][2]," ",  -$starting_angle -90, " ", $circle_radius[$label_no][2], " mm  InsideCircletext\n";
+    print PS_FILE "($text[$label_no][2])", " ", $fontsize[$label_no][2], " ", -$starting_angle -90, " ",
+                    $circle_radius[$label_no][2], " mm  InsideCircletext\n";
 
     # Outer lower circle or textfield
     print PS_FILE "/$fontfamily[$label_no][3] reencodeISO def\n";
     print PS_FILE "/$fontfamily[$label_no][3] findfont\n";
     print PS_FILE " $fontsize[$label_no][3] scalefont setfont\n";
     print PS_FILE "$ps_color[$label_no][3] setrgbcolor \n";
-    print PS_FILE "($text[$label_no][3])" ," ", $fontsize[$label_no][3]," ",  -$starting_angle -90, " ", $circle_radius[$label_no][3] ," mm InsideCircletext\n";
+    print PS_FILE "($text[$label_no][3])", " ", $fontsize[$label_no][3], " ", -$starting_angle -90, " ",
+                    $circle_radius[$label_no][3], " mm InsideCircletext\n";
 
     if ($print_circle_boundaries) {
       print PS_FILE "0 0 0 setrgbcolor\n";
@@ -1047,6 +1071,7 @@ sub print_circles {
       print PS_FILE "stroke\n";
       print PS_FILE "newpath\n";
     }
+    }
     print PS_FILE "grestore\n";
 
     $x_origin  = -$begin_from_left[$label_no];
@@ -1380,6 +1405,7 @@ sub print_textfields {
 
   for ( $i=0; $i < 4; $i++) {
     for ($label_no=0; $label_no < $number_of_labels; $label_no++  ) {
+     if ($label_active[$label_no]) {
       $x_position = $begin_from_left[$label_no]  + $radius_outer + sin($i * $pi/2) *(($radius_outer -$radius_inner)/2);
       if ($debug) {print "print_textfields::X-pos=", $x_position, "\n";}
       $x_position += 5 if ($i == 1);
@@ -1395,21 +1421,22 @@ sub print_textfields {
       my $t = $text[$label_no][$i+4]; # Get the text to print
 
       if (defined $t) {
-	print PS_FILE "/YLine $y_position mm def\n"; # We need this for the linebreak	
-	print PS_FILE "(", $t,")\n";
-	print PS_FILE "$textwidth[$i] mm \n";
-	print PS_FILE "{\n$x_position mm YLine moveto\n";
-	# Ok, here we are, we have to correct the current point by half of
-	# the fontsize
- 	print PS_FILE "\n0 -", $fontsize[$label_no][$i+4]/2 , " rmoveto\n";
-	# Only the textfields above and below the hole in the middle should be centered
-	if ($i == 0 || $i ==2) {
-	  print PS_FILE "center ";
-	}
-	print PS_FILE "show\n";
-	print PS_FILE "/YLine YLine ", $fontsize[$label_no][$i+4], " sub def \n }\n BreakIntoLines\n\n";
-	print PS_FILE "%The next textfield\n";
+        print PS_FILE "/YLine $y_position mm def\n"; # We need this for the linebreak	
+        print PS_FILE "(", $t,")\n";
+        print PS_FILE "$textwidth[$i] mm \n";
+        print PS_FILE "{\n$x_position mm YLine moveto\n";
+        # Ok, here we are, we have to correct the current point by half of
+        # the fontsize
+        print PS_FILE "\n0 -", $fontsize[$label_no][$i+4]/2 , " rmoveto\n";
+        # Only the textfields above and below the hole in the middle should be centered
+        if ($i == 0 || $i ==2) {
+          print PS_FILE "center ";
+        }
+        print PS_FILE "show\n";
+        print PS_FILE "/YLine YLine ", $fontsize[$label_no][$i+4], " sub def \n }\n BreakIntoLines\n\n";
+        print PS_FILE "%The next textfield\n";
       }
+     }
     }
   }
 }
@@ -2036,6 +2063,20 @@ sub set_page_scaling {
 
 }
 
+########################
+sub select_labels {
+  for (my $j = 0; $j < $number_of_labels; $j++) {
+      if ($label_active[$j]) {
+        $ct_clear[$j] -> configure(-state => 'normal');
+        $tf_clear[$j] -> configure(-state => 'normal');
+      } else {
+        $ct_clear[$j] -> configure(-state => 'disabled');
+        $tf_clear[$j] -> configure(-state => 'disabled');
+      }
+  }
+  update_display();
+}
+
 ########################
 sub set_positions {
 
@@ -2368,6 +2409,10 @@ the whole page to get perfect circles with your printer.
 
 You can move the circles around the page using this menu.
 
+=item I<Top Label / Bottom Label>
+
+Select which labels will be generated. The input fields for unselected labels are disabled.
+
 =item I<Tickmarks>
 
 There are many cd-label sheets on the market, so you can move the circles around the page. To make this
